@@ -17,6 +17,8 @@
 #'  mean relative expression level of phylostrata belonging to the same phylostratum class.
 #'  In case \code{ratio} = TRUE, the ratio of the mean relative expression level of 
 #'  the two phylostrata classes is plotted as lines within the barplot. This parameter can only be used for 2 class comparisons.
+#'  @param p.adjust.method correction method to adjust p-values for multiple comparisons (see \code{\link{p.adjust}} for possible methods).
+#'   E.g., \code{p.adjust.method = "BH"} (Benjamini & Hochberg (1995)) or \code{p.adjust.method = "bonferroni"} (Bonferroni correction).
 #'  @param \dots default graphics parameters. 
 #'  @return A barplot comparing Phylostratum-Classes by its mean relative expression levels.
 #' Significant stages are marked by '*' referring to statistically significant differences:
@@ -27,6 +29,11 @@
 #'
 #' (3) '***' = P-Value <= 0.0005  
 #' 
+#' @details 
+#' In case a large number of developmental stages is included in the input \code{ExpressionSet},
+#'  p-values returned by \code{PlotBarRE} should be adjusted for multiple comparisons which can be done
+#'  by specifying the \code{p.adjust.method} argument.
+#'  
 #' @references 
 #' 
 #' Quint M et al. 2012. "A transcriptomic hourglass in plant embryogenesis". Nature (490): 98-101.
@@ -40,28 +47,39 @@
 #' @examples
 #' 
 #' # read standard phylotranscriptomics data
-#'
 #' data(PhyloExpressionSetExample)
 #' data(DivergenceExpressionSetExample)
 #' 
 #' # example PhyloExpressionSet
-#' 
-#' PlotBarRE(PhyloExpressionSetExample,Groups = list(c(1:3), c(4:12)))
+#' PlotBarRE(ExpressionSet = PhyloExpressionSetExample,
+#'           Groups        = list(c(1:3), c(4:12)))
+#'
 #'
 #' # example DivergenceExpressionSet
+#' PlotBarRE(ExpressionSet = DivergenceExpressionSetExample,
+#'           Groups        = list(c(1:5), c(6:10)))
 #'
-#' PlotBarRE(DivergenceExpressionSetExample,Groups = list(c(1:5), c(6:10)))
 #'
+#' # Perform PlotBarRE() with p-value adjustment method Benjamini & Hochberg (1995)
+#' PlotBarRE(ExpressionSet   = PhyloExpressionSetExample,
+#'           Groups          = list(c(1:3), c(4:12)),
+#'           p.adjust.method = "BH")
+#'        
+#'              
 #' # Example: plot ratio
 #' # the ratio curve visualizes the ratio between bar 1 / bar 2
 #' # the z - axis shows the corresponding ratio value of bar 1 / bar 2
-#'
-#' PlotBarRE(PhyloExpressionSetExample,Groups = list(c(1:3), c(4:12)), ratio = TRUE)
-#'
+#' PlotBarRE(ExpressionSet = PhyloExpressionSetExample,
+#'           Groups        = list(c(1:3), c(4:12)),
+#'           ratio         = TRUE)
 #' 
 #' @export
 
-PlotBarRE <- function(ExpressionSet,Groups = NULL,wLength = 0.1,ratio = FALSE,...)
+PlotBarRE <- function(ExpressionSet,
+                      Groups          = NULL,
+                      wLength         = 0.1,
+                      ratio           = FALSE,
+                      p.adjust.method = NULL, ...)
 {
         
         is.ExpressionSet(ExpressionSet)
@@ -99,16 +117,23 @@ PlotBarRE <- function(ExpressionSet,Groups = NULL,wLength = 0.1,ratio = FALSE,..
         ### as well as the Std.Error of the relative expression levels
         ### included in each PS-Group
         for(i in 1:nGroups){
-                MeanREClassValues[i , ] <- colMeans(REmatrix[match(as.character(Groups[[i]]), rownames(REmatrix)) , ])
-                StdErr.RE.ClassValues[i , ] <- apply(REmatrix[match(as.character(Groups[[i]]), rownames(REmatrix)) , ],2,std.error)
+                MeanREClassValues[i , ] <- colMeans(REmatrix[match(as.character(Groups[[i]]),
+                                                                   rownames(REmatrix)) , ])
+                
+                StdErr.RE.ClassValues[i , ] <- apply(REmatrix[match(as.character(Groups[[i]]),
+                                                                    rownames(REmatrix)) , ],2,std.error)
         }   
         
         if(nGroups == 2){
                 for(j in 1:(nCols-2)){
                         
-                        testForConstantValues <- try(kruskal.test(list(REmatrix[match(as.character(Groups[[1]]), rownames(REmatrix)) , j], REmatrix[match(as.character(Groups[[2]]), rownames(REmatrix)) , j])), silent = FALSE)
+                        testForConstantValues <- try(stats::kruskal.test(list(REmatrix[match(as.character(Groups[[1]]),
+                                                                                      rownames(REmatrix)) , j],
+                                                                       REmatrix[match(as.character(Groups[[2]]),
+                                                                                      rownames(REmatrix)) , j])),
+                                                     silent = FALSE)
                         
-                        if(is(testForConstantValues, "try-error")){
+                        if(methods::is(testForConstantValues, "try-error")){
                                 warning("Something went wrong with the Kruskal-Wallis Rank Sum Test... the p-value has been set to p = 1.")
                                 pValues[j] <- 1
                         } 
@@ -130,11 +155,16 @@ PlotBarRE <- function(ExpressionSet,Groups = NULL,wLength = 0.1,ratio = FALSE,..
                                 AnovaListValues[k] <- list(REmatrix[match(as.character(Groups[[k]]), rownames(REmatrix)) , s])
                         }
                         
-                        pValues[s] <- kruskal.test(AnovaListValues)$p.value
+                        pValues[s] <- stats::kruskal.test(AnovaListValues)$p.value
                         
                 }
         }
         
+        if(!is.null(p.adjust.method)){
+                
+                pValues <- stats::p.adjust(pValues, method = p.adjust.method, n = nPS)
+        }
+        
         pValNames <- rep("",nCols-2)
         pValNames[which(pValues <= 0.05)] <- "*"
         pValNames[which(pValues <= 0.005)] <- "**"
@@ -158,16 +188,22 @@ PlotBarRE <- function(ExpressionSet,Groups = NULL,wLength = 0.1,ratio = FALSE,..
                 do.call(graphics::text,c(list(apply(REBarPlot,2,mean),0.95,labels = pValNames),
                                          dots[!is.element(names(dots),c(barplot.args))]))
                 
-                suppressWarnings(arrows(x0 = REBarPlot,y0 = ifelse(MeanREClassValues > 0,MeanREClassValues, (1/999)),x1 = REBarPlot,
+                suppressWarnings(graphics::arrows(x0 = REBarPlot,y0 = ifelse(MeanREClassValues > 0,MeanREClassValues, (1/999)),x1 = REBarPlot,
                        y1 = ifelse((StdErr.RE.ClassValues) == 0,MeanREClassValues + (1/999),
                                    MeanREClassValues + StdErr.RE.ClassValues),code = 2, angle = 90, length = wLength))
                 
-                par(xpd = TRUE)
-                legend("topleft",inset = c(+0.2,0),legend = paste("Group ",1:length(Groups),sep = ""),
-                       fill = barColors,bty = "n",cex = 1.3,ncol = ceiling(nGroups/2))
-                par(xpd = FALSE)
+                graphics::par(xpd = TRUE)
+                graphics::legend("topleft",
+                                 inset  = c(+0.2,0),
+                                 legend = paste("Group ",1:length(Groups),sep = ""),
+                                 fill   = barColors,
+                                 bty    = "n",
+                                 cex    = 1.3,
+                                 ncol   = ceiling(nGroups/2))
+                
+                graphics::par(xpd = FALSE)
                 if(nGroups == 2){
-                        lines(colMeans(REBarPlot), REFoldChangeOfMeanREValues,lty = 2,lwd = 5,col = "darkblue")
+                        graphics::lines(colMeans(REBarPlot), REFoldChangeOfMeanREValues,lty = 2,lwd = 5,col = "darkblue")
                         do.call(graphics::axis,c(list(4,seq(0,1,0.2),format(seq(0,max(FoldChangeOfMeanREValues),length.out = 6),digits = 2)),
                                                  dots[!is.element(names(dots),c(text.args))]))
                 }
@@ -181,11 +217,11 @@ PlotBarRE <- function(ExpressionSet,Groups = NULL,wLength = 0.1,ratio = FALSE,..
                 do.call(graphics::text,c(list(colMeans(REBarPlot),1.15,labels = pValNames),
                                          dots[!is.element(names(dots),c(barplot.args))]))
                 
-                suppressWarnings(arrows(x0 = REBarPlot,y0 = ifelse(MeanREClassValues > 0,MeanREClassValues, (1/999)),x1 = REBarPlot,
+                suppressWarnings(graphics::arrows(x0 = REBarPlot,y0 = ifelse(MeanREClassValues > 0,MeanREClassValues, (1/999)),x1 = REBarPlot,
                        y1 = ifelse((StdErr.RE.ClassValues) == 0,MeanREClassValues + (1/999),
                                    MeanREClassValues + StdErr.RE.ClassValues),code = 2, angle = 90, length = wLength))
                 
-                legend("topleft",legend = paste("Group ",1:length(Groups),sep = ""),fill = barColors,bty = "n",ncol = ceiling(nGroups/2))
+                graphics::legend("topleft",legend = paste("Group ",1:length(Groups),sep = ""),fill = barColors,bty = "n",ncol = ceiling(nGroups/2))
         }
         
 }
