@@ -153,12 +153,18 @@ ReductiveHourglassTest <- function(ExpressionSet,
         real_age <- vector(mode = "numeric",length = nCols-2)
         real_age <- cpp_TAI(as.matrix(ExpressionSet[ , 3:nCols]),as.vector(ExpressionSet[ , 1]))
         ### compute the real reductive hourglass scores of the observed phylotranscriptomics pattern
-        real_score <- rhScore(real_age,early = modules[[1]],mid = modules[[2]],late = modules[[3]],
-                              method = "min",scoringMethod = "mean-mean")
+        real_score <- rhScore(real_age,
+                              early         = modules[[1]],
+                              mid           = modules[[2]],
+                              late          = modules[[3]],
+                              method        = "min",
+                              scoringMethod = "mean-mean")
         
         ### compute the bootstrap matrix 
         if (is.null(custom.perm.matrix)){
-                resMatrix <- cpp_bootMatrix(as.matrix(ExpressionSet[ , 3:nCols]),as.vector(ExpressionSet[ , 1]),as.numeric(permutations))       
+                resMatrix <- cpp_bootMatrix(as.matrix(ExpressionSet[ , 3:nCols]),
+                                            as.vector(ExpressionSet[ , 1]),
+                                            as.numeric(permutations))       
         }
         
         else if (!is.null(custom.perm.matrix)){
@@ -179,34 +185,32 @@ ReductiveHourglassTest <- function(ExpressionSet,
                 # plot histogram of scores
                 normDensity <- function(x){
                         
-                        return(dnorm(x,mu,sigma))
+                        return(stats::dnorm(x,mu,sigma))
                         
                 }
                 
                 if(lillie.test)
-                        par(mfrow = c(2,2))
+                        graphics::par(mfrow = c(2,2))
                 if(!lillie.test)
-                        par(mfrow = c(1,3))
+                        graphics::par(mfrow = c(1,3))
                 
                 fitdistrplus::descdist(score_vector, boot = permutations)
                 
-                curve( expr = normDensity,
-                       xlim = c(min(score_vector),max(score_vector,real_score)),
-                       col  = "steelblue",
-                       lwd  = 5,
-                       xlab = "Scores",
-                       ylab = "Frequency" )
+                graphics::curve( expr = normDensity,
+                                 xlim = c(min(score_vector),max(score_vector,real_score)),
+                                 col  = "steelblue",
+                                 lwd  = 5,
+                                 xlab = "Scores",
+                                 ylab = "Frequency" )
                 
-                hist( x      = score_vector,
-                      prob   = TRUE,
-                      add    = TRUE, 
-                      breaks = permutations / (0.01 * permutations) )
+                graphics::hist( x      = score_vector,
+                                prob   = TRUE,
+                                add    = TRUE, 
+                                breaks = permutations / (0.01 * permutations) )
                 
-                rug(score_vector)
+                graphics::rug(score_vector)
                 # plot a red line at the position where we can find the real rh value
-                abline(v = real_score, lwd = 5, col = "darkred")
-                
-                #legend("topleft", legend = "A", bty = "n")
+                graphics::abline(v = real_score, lwd = 5, col = "darkred")
                 
                 p.vals_vec <- vector(mode = "numeric", length = runs)
                 lillie_vec <- vector(mode = "logical", length = runs)
@@ -214,7 +218,7 @@ ReductiveHourglassTest <- function(ExpressionSet,
                 
                 cat("\n")
                 
-                if(parallel){
+                if (parallel){
                         
                         ### Parallellizing the sampling process using the 'doParallel' and 'parallel' package
                         ### register all given cores for parallelization
@@ -243,8 +247,7 @@ ReductiveHourglassTest <- function(ExpressionSet,
                         
                 }
                 
-                
-                if(!parallel){
+                if (!parallel){
                         
                         
                         # sequential computations of p-values 
@@ -254,9 +257,9 @@ ReductiveHourglassTest <- function(ExpressionSet,
 #                                 
 #                         }
                         
-                        for(i in 1:runs){
+                        for (i in 1:runs){
                                 
-                                if(lillie.test){
+                                if (lillie.test){
                                         rht <- ReductiveHourglassTest( ExpressionSet = ExpressionSet,
                                                                        permutations  = permutations,
                                                                        lillie.test   = TRUE, 
@@ -265,7 +268,7 @@ ReductiveHourglassTest <- function(ExpressionSet,
                                                                        runs          = NULL )
                                 } 
                                         
-                               if(!lillie.test){
+                               if (!lillie.test){
                                        
                                         rht <- ReductiveHourglassTest( ExpressionSet        = ExpressionSet,
                                                                        permutations         = permutations,
@@ -289,39 +292,36 @@ ReductiveHourglassTest <- function(ExpressionSet,
                 
                 #cat("\n")
                 
-                plot( x    = p.vals_vec,
-                      type = "l" , 
-                      lwd  = 6, 
-                      ylim = c(0,1), 
-                      col  = "darkblue", 
-                      xlab = "Runs", 
-                      ylab = "p-value" )
+                graphics::plot( x    = p.vals_vec,
+                                type = "l" , 
+                                lwd  = 6, 
+                                ylim = c(0,1), 
+                                col  = "darkblue", 
+                                xlab = "Runs", 
+                                ylab = "p-value" )
 
-                abline(h = 0.05, lty = 2, lwd = 3)
-                #legend("topleft", legend = "B", bty = "n")
-                
-                if(lillie.test){
+                graphics::abline(h = 0.05, lty = 2, lwd = 3)
+
+                if (lillie.test){
                         tbl <- table(factor(lillie_vec, levels = c("FALSE","TRUE")))
                         
-                        barplot( height    = tbl/sum(tbl), 
-                                 beside    = TRUE, 
-                                 names.arg = c("FALSE", "TRUE"), 
-                                 ylab      = "relative frequency", 
-                                 main      = paste0("runs = ",runs) )
-                        
-                        #legend("topleft", legend = "C", bty = "n")
+                        graphics::barplot( height    = tbl/sum(tbl), 
+                                           beside    = TRUE, 
+                                           names.arg = c("FALSE", "TRUE"), 
+                                           ylab      = "Relative Frequency", 
+                                           main      = paste0("runs = ",runs) )
                 }
         }
         
         
         #if(real_score >= 0)
-        pval <- pnorm(real_score,mean = mu,sd = sigma,lower.tail = FALSE)
+        pval <- stats::pnorm(real_score,mean = mu,sd = sigma,lower.tail = FALSE)
         
         #if(real_score < 0)
         #pval <- pnorm(real_score,mean=mu,sd=sigma,lower.tail=TRUE)
         ### computing the standard deviation of the sampled TAI values for each stage separately
         sd_vals <- vector(mode = "numeric",length = nCols-2)
-        sd_vals <- apply(resMatrix,2,sd)
+        sd_vals <- apply(resMatrix,2,stats::sd)
         
         if(lillie.test){
                 # perform Lilliefors K-S-Test
